<?php

/**
 * Intercept template variables
 *
 * @param $hook
 *   The name of the theme function being executed
 * @param $vars
 *   A sequential array of variables passed to the theme function.
 */
function _phptemplate_variables($hook, $vars) {
  switch ($hook) {
    case 'page':
      if (module_exists('javascript_aggregator') && $vars['scripts']) {
        $vars['scripts'] = javascript_aggregator_cache($vars['scripts']);
      }
      drupal_add_css($vars['directory'] .'/modules.css', 'theme', 'all');
      drupal_add_css($vars['directory'] .'/common.css', 'theme', 'all');
      $vars['styles'] = drupal_get_css();
      break;
    case 'node':
      // Display info only on certain node types.
      if (theme_get_setting('toggle_node_info_' . $vars['node']->type)) {
        $vars['submitted'] =  t('!user - <abbr class="created" title="!microdate">!date</abbr>', array(
          '!user' => theme('username', $vars['node']),
          '!date' => format_date($vars['node']->created),
          '!microdate' => format_date($vars['node']->created,'custom', "Y-m-d\TH:i:sO")
        ));
      }
      else {
        $vars['submitted'] = '';
      }
      if (module_exists('taxonomy')) {
        $vocabs = taxonomy_get_vocabularies();
        foreach($vocabs as $vocab) {
          $tags = array();
          $terms = taxonomy_node_get_terms_by_vocabulary($vars['node']->nid, $vocab->vid);
          foreach ($terms as $term) {
            $tags['taxonomy_term_'. $term->tid] = array(
              'title' => $term->name,
              'href' => taxonomy_term_path($term),
              'attributes' => array('rel' => 'tag', 'title' => strip_tags($term->description))
            );
          }
          if ($tags) {
            $vars['tags_'. $vocab->vid] = theme('links', $tags, array('class' => 'links inline'));
          }
        }
      }
      break;

    case 'comment':
      if ($vars['submitted']) {
        $vars['submitted'] =  t('!user - <abbr class="created" title="!microdate">!date</abbr>', array(
          '!user' => theme('username', $vars['comment']),
          '!date' => format_date($vars['comment']->timestamp),
          '!microdate' => format_date($vars['comment']->timestamp,'custom', "Y-m-d\TH:i:sO")
        ));
      }
      break;
  }

  return $vars;
}
